package adapterclient

import (
	"encoding/json"
	"log"

	"github.com/pivotal-cf/on-demand-services-sdk/bosh"
	"github.com/pivotal-cf/on-demand-services-sdk/serviceadapter"
)

func (a *Adapter) CreateBinding(bindingID string, deploymentTopology bosh.BoshVMs, manifest []byte, requestParams map[string]interface{}, logger *log.Logger) (serviceadapter.Binding, error) {
	errs := func(err error) (serviceadapter.Binding, error) {
		return serviceadapter.Binding{}, err
	}
	serialisedBoshVMs, err := json.Marshal(deploymentTopology)
	if err != nil {
		return errs(err)
	}
	serialisedRequestParams, err := json.Marshal(requestParams)
	if err != nil {
		return errs(err)
	}

	stdout, stderr, exitCode, err := a.CommandRunner.Run(a.ExternalBinPath, "create-binding", bindingID, string(serialisedBoshVMs), string(manifest), string(serialisedRequestParams))

	e := newErrorFactory(a.ExternalBinPath, stdout, stderr)
	if err != nil {
		return errs(e.adapterError(err))
	}

	switch *exitCode {
	case SuccessExitCode:
		break
	case serviceadapter.NotImplementedExitCode:
		return errs(e.commandNotImplementedError("create-binding"))
	case serviceadapter.AppGuidNotProvidedErrorExitCode:
		return errs(serviceadapter.NewAppGuidNotProvidedError(e.exitCodeError(*exitCode)))
	case serviceadapter.BindingAlreadyExistsErrorExitCode:
		return errs(serviceadapter.NewBindingAlreadyExistsError(e.exitCodeError(*exitCode)))
	default:
		return errs(e.exitCodeError(*exitCode))
	}

	logger.Printf("service adapter ran create-binding successfully, stderr logs: %s", string(stderr))

	var adapterBinding serviceadapter.Binding
	if err := json.Unmarshal(stdout, &adapterBinding); err != nil {
		return errs(e.invalidJSONError(err))
	}

	return adapterBinding, nil
}
