package adapterclient

import (
	"encoding/json"
	"log"

	"github.com/pivotal-cf/on-demand-services-sdk/serviceadapter"
)

func (a *Adapter) GenerateDashboardUrl(instanceID string, plan serviceadapter.Plan, manifest []byte, logger *log.Logger) (string, error) {
	plan.Properties = SanitiseForJSON(plan.Properties)
	planJSON, err := json.Marshal(plan)
	if err != nil {
		return "", err
	}

	stdout, stderr, exitCode, err := a.CommandRunner.Run(a.ExternalBinPath, "dashboard-url", instanceID, string(planJSON), string(manifest))

	e := newErrorFactory(a.ExternalBinPath, stdout, stderr)
	if err != nil {
		return "", e.adapterError(err)
	}

	switch *exitCode {
	case SuccessExitCode:
		logger.Printf("service adapter ran dashboard-url successfully, stderr logs: %s", string(stderr))
		break
	case serviceadapter.NotImplementedExitCode:
		return "", e.commandNotImplementedError("dashboard-url")
	default:
		return "", e.exitCodeError(*exitCode)
	}

	dashboardURL := serviceadapter.DashboardUrl{}

	return string(dashboardURL.DashboardUrl), json.Unmarshal(stdout, &dashboardURL)
}
