package adapterclient

import (
	"encoding/json"
	"log"

	"github.com/pivotal-cf/on-demand-services-sdk/bosh"
	"github.com/pivotal-cf/on-demand-services-sdk/serviceadapter"
)

func (a *Adapter) DeleteBinding(bindingID string, deploymentTopology bosh.BoshVMs, manifest []byte, requestParams map[string]interface{}, logger *log.Logger) error {
	serialisedBoshVMs, err := json.Marshal(deploymentTopology)
	if err != nil {
		return err
	}

	serialisedRequestParams, err := json.Marshal(requestParams)
	if err != nil {
		return err
	}

	stdout, stderr, exitCode, err := a.CommandRunner.Run(a.ExternalBinPath, "delete-binding", bindingID, string(serialisedBoshVMs), string(manifest), string(serialisedRequestParams))

	e := newErrorFactory(a.ExternalBinPath, stdout, stderr)
	if err != nil {
		return e.adapterError(err)
	}

	genericExitCodeError := e.exitCodeError(*exitCode)
	switch *exitCode {
	case SuccessExitCode:
		logger.Printf("service adapter ran delete-binding successfully, stderr logs: %s", string(stderr))
		return nil
	case serviceadapter.NotImplementedExitCode:
		return e.commandNotImplementedError("delete-binding")
	case serviceadapter.BindingNotFoundErrorExitCode:
		return serviceadapter.NewBindingNotFoundError(genericExitCodeError)
	default:
		return genericExitCodeError
	}
}
