package main

import (
	"flag"
	"io/ioutil"

	"os"

	"github.com/pivotal-cf/on-demand-service-broker/cloud_foundry_client"
	"github.com/pivotal-cf/on-demand-service-broker/deleter"
	"github.com/pivotal-cf/on-demand-service-broker/loggerfactory"
	"gopkg.in/yaml.v2"
)

func main() {
	loggerFactory := loggerfactory.New(os.Stdout, "delete-all-service-instances", loggerfactory.Flags)
	logger := loggerFactory.New()

	configFilePath := flag.String("configFilePath", "", "path to config file")
	flag.Parse()

	rawConfig, err := ioutil.ReadFile(*configFilePath)
	if err != nil {
		logger.Fatalf("Error reading config file: %s", err)
	}

	var deleterConfig deleter.Config
	err = yaml.Unmarshal(rawConfig, &deleterConfig)
	if err != nil {
		logger.Fatalf("Invalid config file: %s", err)
	}

	cfAuthenticator, err := deleterConfig.CF.NewAuthHeaderBuilder(deleterConfig.DisableSSLCertVerification)
	if err != nil {
		logger.Fatalf("error creating CF authorization header builder: %s", err)
	}

	cfClient, err := cloud_foundry_client.New(
		deleterConfig.CF.URL,
		cfAuthenticator,
		[]byte(deleterConfig.CF.TrustedCert),
		deleterConfig.DisableSSLCertVerification,
	)
	if err != nil {
		logger.Fatalf("error creating Cloud Foundry client: %s", err)
	}

	deleteTool := deleter.New(cfClient, deleterConfig.PollingInterval, logger)
	err = deleteTool.DeleteAllServiceInstances(deleterConfig.ServiceCatalog.ID)
	if err != nil {
		logger.Fatalln(err)
	}

	logger.Println("FINISHED DELETES")
}
