package main

import (
	"flag"
	"os"

	"github.com/pivotal-cf/on-demand-service-broker/loggerfactory"
	"github.com/pivotal-cf/on-demand-service-broker/upgrader"
)

func main() {
	loggerFactory := loggerfactory.New(os.Stdout, "upgrade-all-service-instances", loggerfactory.Flags)
	logger := loggerFactory.New()

	brokerUsername := flag.String("brokerUsername", "", "username for the broker")
	brokerPassword := flag.String("brokerPassword", "", "password for the broker")
	brokerUrl := flag.String("brokerUrl", "", "url of the broker")
	pollingInterval := flag.Int("pollingInterval", 0, "interval for checking the upgrade in seconds")
	flag.Parse()

	if *brokerUsername == "" || *brokerPassword == "" || *brokerUrl == "" {
		logger.Fatalln("the brokerUsername, brokerPassword and brokerUrl are required to function")
	}

	if *pollingInterval <= 0 {
		logger.Fatalln("the pollingInterval must be greater than zero")
	}

	listener := upgrader.NewLoggingListener(logger)
	upgradeTool := upgrader.New(*brokerUsername, *brokerPassword, *brokerUrl, *pollingInterval, listener)

	err := upgradeTool.Upgrade()
	if err != nil {
		logger.Fatalln(err.Error())
	}
}
