package loggerfactory

import (
	"context"
	"fmt"
	"io"
	"log"

	"github.com/pborman/uuid"
	"github.com/pivotal-cf/on-demand-service-broker/brokercontext"
)

const Flags = log.Ldate | log.Ltime | log.Lmicroseconds | log.LUTC

type LoggerFactory struct {
	out  io.Writer
	name string
	flag int
}

func New(out io.Writer, name string, flag int) *LoggerFactory {
	return &LoggerFactory{out: out, name: name, flag: flag}
}

func (l *LoggerFactory) NewWithContext(ctx context.Context) *log.Logger {
	if brokercontext.GetReqID(ctx) == "" {
		return l.New()
	}

	prefix := fmt.Sprintf("[%s] [%s] ", l.name, brokercontext.GetReqID(ctx))
	return log.New(l.out, prefix, l.flag)
}

func (l *LoggerFactory) NewWithRequestID() *log.Logger {
	prefix := fmt.Sprintf("[%s] [%s] ", l.name, uuid.New())
	return log.New(l.out, prefix, l.flag)
}

func (l *LoggerFactory) New() *log.Logger {
	prefix := fmt.Sprintf("[%s] ", l.name)
	return log.New(l.out, prefix, l.flag)
}
